@@ -69,7 +69,8 @@ def service(urlpath=None, auto_parse=True, static=False, accel=False,
             cache=False, force_download=False, content_disposition=False,
             auto_close_file=True, check_abusive=True, check_perm=True,
             postmortem_debug=False, force_define=False, log_exc=True,
-            use_one_time_pad=True, safe=True, ssl=None, **output):
+            use_one_time_pad=True, safe=True, ssl=None, csp=None,
+            **output):
 
     for k, v in output.iteritems():
         if not (k and k.isalnum() and callable(v)):
@@ -82,6 +83,11 @@ def service(urlpath=None, auto_parse=True, static=False, accel=False,
     if not safe:
         use_one_time_pad = False
 
+    if content_disposition is True:
+        force_download = False
+    elif force_download is True:
+        content_disposition = False
+
     def decorator(f):
         srv_path = (urlpath or f.__name__).strip('/')
 
@@ -207,6 +213,7 @@ def service(urlpath=None, auto_parse=True, static=False, accel=False,
             else:
                 return ret
 
+        wrapper.csp = csp
         wrapper.ssl = ssl
         wrapper.safe = safe
         wrapper.cache = cache
@@ -313,6 +320,7 @@ def static(urlpath, root, index='index.html', **argd):
 
     argd.setdefault('cache', True)
     argd.setdefault('log_exc', False)
+    argd.setdefault('csp', "default-src 'self' 'unsafe-eval'")
 
     @service(urlpath, auto_parse=False, static=True, safe=False, **argd)
     def serve_file(*args, **argd):
@@ -333,6 +341,7 @@ def static(urlpath, root, index='index.html', **argd):
 
     return serve_file
 
+
 static(conf.JFANERY_URLPATH, conf.JFANERY_DIRPATH)
 
 
