@@ -441,6 +441,7 @@ class storage(object):
                 else:
                     record._mark = UPDATE
                     self._dirty[record._store].add(record)
+            return records[0] if len(records) == 1 else records
         finally:
             logger.debug("%s %0.6f update %d" % (self._txn, timestamp() - _start, len(records)))    # noqa
 
@@ -457,6 +458,7 @@ class storage(object):
                     raise exc.UnstoredRecord(record)
                 record._mark = DELETE
                 self._dirty[record._store].add(record)
+            return True
         finally:
             logger.debug("%s %0.6f delete %d" % (self._txn, timestamp() - _start, len(records)))    # noqa
 
